On 24 July 2013 01:54, Aaro Koskinen <[email protected]> wrote: > Some functions on switch path use msleep() which is inaccurate, and > depends on HZ. With HZ=100 msleep(1) takes actually over ten times longer. > Using usleep_range() we get more accurate sleeps. > > I measured the "pfunc_slewing_done" polling to take 300us at max (on > 2.3GHz dual-processor Xserve G5), so using 500us sleep there should > be fine. > > With the patch, g5_switch_freq() duration drops from ~50ms to ~10ms on > Xserve with HZ=100. > > Signed-off-by: Aaro Koskinen <[email protected]> > --- > drivers/cpufreq/pmac64-cpufreq.c | 6 +++--- > 1 file changed, 3 insertions(+), 3 deletions(-)
Looks fine to me as well.. Acked-by: Viresh Kumar <[email protected]> _______________________________________________ Linuxppc-dev mailing list [email protected] https://lists.ozlabs.org/listinfo/linuxppc-dev
